#
# spec file for package python-os-win
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname os-win
Name:           python-os-win
Version:        1.4.1
Release:        1.2
Summary:        Hyper-V library for OpenStack projects
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-Sphinx
BuildRequires:  python-ddt >= 1.0.1
BuildRequires:  python-devel
BuildRequires:  python-eventlet >= 0.18.2
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-oslo.concurrency >= 3.8.0
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslo.log >= 3.11.0
BuildRequires:  python-oslosphinx >= 4.7.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.8
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-Babel >= 2.3.4
Requires:       python-eventlet >= 0.18.2
Requires:       python-oslo.concurrency >= 3.8.0
Requires:       python-oslo.config >= 3.14.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.log >= 3.11.0
Requires:       python-oslo.service >= 1.10.0
Requires:       python-oslo.utils >= 3.18.0
Requires:       python-pbr >= 1.8
BuildArch:      noarch

%description
Library contains Windows / Hyper-V code commonly used in the OpenStack projects:
nova, cinder, networking-hyperv.

%package doc
Summary:        Documentation for OpenStack Windows/Hyper-V Library
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 4.7.0

%description doc
Documentation for the Hyper-V library.

%prep
%autosetup -n %{sname}-%{version}
%py_req_cleanup

%build
%{py2_build}
%{__python2} setup.py build_sphinx
rm -rf html/.{doctrees,buildinfo}

%install
%{py2_install}
install -p -D -m 644 doc/build/man/os-win.1 %{buildroot}/%{_mandir}/man1/os-win.1

%check
%{__python2} setup.py test

%files
%doc README.rst ChangeLog
%license LICENSE
%{python2_sitelib}/os_win*
%{python2_sitelib}/*.egg-info
%{_mandir}/man1/os-win.1*

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Mon Mar 27 2017 cloud-devel@suse.de
- update to version 1.4.1:
  - vmutils: Adds vnuma_enabled argument to update_vm
  - vmutils: set all *DataRoot paths to the same value
  - removes the VirtualSystemType kwarg when fetching VMs
  - Update .gitreview for stable/ocata
  - Update UPPER_CONSTRAINTS_FILE for stable/ocata
  - pathutils: Adds retry decorator to rmdir
  - vmutils: Allows updating and disabling instance RemoteFX
  - vmutils: Adds remove_all_pci_devices method
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.4.0:
  - Non-clustered VM live migration fix
  - Removes all references to openstack.common
  - Move unit tests to a separate folder
  - Add methods for handling file ACLs
  - Allow setting automatic vm shutdown action
  - Implements qos methods in networkutils
  - Rename argument in iscsi_utils, breaking os-brick
  - Add method for retrieving vm config root dir
  - Add Constraints support
  - Ensure Win32 API calls do not block
  - vmutils: honor host argument
  - FibreChannel: ignore unsupported HBA adapters
  - Show team and repo badges on README
  - Changed author and author-email
  - Avoid opening parents when fetching VHD info
  - Removes unnecessary oslo.service requirement
  - Use assertEqual() instead of assertDictEqual()
  - Handle sporadic iSCSI initiator errors
  - Adds VLAN trunk mode support
  - Adds nested virtualization support
  - Fix iscsi volumes not being attached
  - Adds Hyper-V PCI Passthrough support
  - VM Importing/Exporting
  - Retry on opening named pipe failures
  - Fix clustered vm live migration
  - Ensure GetLastError gets called in the right thread
  - Pin docutils version
  - Add hbaapi path config option
  - use unpatched socket module to get addresses
  - Fix clustered VM migration status polling
  - Avoid using diskpart for disk rescans
  - Updated from global requirements
* Tue Nov 15 2016 dmueller@suse.com
- update to 1.2.1:
  * Ensure GetLastError gets called in the right thread
  * Retry on opening named pipe failures
  * Handle sporadic iSCSI initiator errors
  * Fix clustered VM migration status polling
  * VM Importing/Exporting
  * Non-clustered VM live migration fix
  * Fix clustered vm live migration
  * Add method for retrieving vm config root dir
  * vmutils: honor host argument
  * Avoid using diskpart for disk rescans
  * Ensure Win32 API calls do not block
  * Update .gitreview for stable/newton
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 1.2.0
  * Remove discover from test-requirements
  * Resolves flake8 errors
  * Removes Windows Server 2008 R2 specific code
  * TrivialFix: Remove cfg import unused
  * Updates README.rst
  * Refactors wmi exceptions usage
  * Add public method for destroying planned vms
  * Fix DNS zone serial number retrieval
  * Adds docstrings to the public methods of hostutils and jobutils
  * TrivialFix: Remove logging import unused
  * Updated from global requirements
  * Retry failed disk rescans
  * Sets parent class for ISCSITargetUtils
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.1.0
  * iSCSI tgt utils: remove workaround needed by old WMI lib
  * Hyper-V: Added checking secure VMs status
  * Adds method for returning DNS Zone properties
  * Add utils for managing DNS operations
  * Add instance job terminate timeout
  * Fix for VM's not getting IP due to missing SG rules
  * Properly handle stopping VM jobs
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 1.0.0:
  * Fixes loading HGS namespace on early builds of Windows 10
  * Add method for checking whether a share is local
  * Fix disk rescan method
  * Fix event handle leaks
  * Hyper-V: Shielded VMs
  * Updated from global requirements
  * Fix iSCSI initiator utils docstring
  * iSCSI utils: accept rescan_attempts arg in login method
  * Add missing wmi to requirements.txt
  * Updated from global requirements
  * Add method for retrieving local share paths
  * Updated from global requirements
  * Events: use tpool only if thread module is patched
  * Fix event listeners
  * Updated from global requirements
  * Adds missing attribute from get_cpus_info query
  * Fix retrieving VM notes race condition
  * Fix retrieving VHDX block size
  * Updated from global requirements
  * Fix retrieving VM physical disk mapping
  * Copies get_share_capacity_info to diskutils
  * python3: Fixes vhdutils internal VHDX size
  * Consistently raise exception if port not found
  * Ensure vmutils honors the host argument
  * Sets OsWinBaseTestCase as base class for unit tests
  * Fixes PyMI compatiblity issue
  * Fixes vmutils take_vm_snapshot method
  * Adds check for VLAN and VSID operations
  * Fix named pipe handler cleanup regression
  * Fixes vmutils get_vm_generation method
  * Improve clusterutils with new pyMI features
  * Ensure namedpipe IO workers clean up handles when stopping
  * switch to post-versioning
  * Bump version to 0.3.3
  * Deprecate volumeutils v1
  * Instance event listener: ignore exceptions
  * Replace associators with direct queries (part 2)
  * Fix serial console worker blocking Nova
  * Adds Hyper-V Cluster related utils
  * Fixed _winreg OpenKey parameter
  * Bump version to 0.3.2
- Use .spec from upstream rpm-packaging project
- Use renderspec source service to update .spec
* Wed Mar 30 2016 dmueller@suse.com
- fix license
* Mon Mar 14 2016 tbechtold@suse.com
- Update Requires
* Mon Mar 14 2016 tbechtold@suse.com
- Initial packaging (version 0.3.1)
